utils

package
v0.0.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const CmdlinePath = "/proc/cmdline"

CmdlinePath is the default location for the cmdline.

Variables

This section is empty.

Functions

func ClearDir

func ClearDir(dir string) error

ClearDir is a helper function to remove all files in a directory.

func ClearScreen

func ClearScreen()

ClearScreen will clear the screen of all text.

func DashMac

func DashMac(mac string) string

DashMac makes a mac address something that can be used in a URL.

func GetBlockDeviceSize

func GetBlockDeviceSize(device string) (int64, error)

GetBlockDeviceSize will read the size from the /sys/block for a specific block device.

func ParseCmdLine

func ParseCmdLine(cmdlinePath string) (m map[string]string, err error)

ParseCmdLine will read through the command line and return the source and destination.

Types

This section is empty.

Jump to